.rc-slider-rail {
  background-color: var(--background-color-1-rc-slider);
}

.rc-slider-track {
  background-color: var(--background-color-2-rc-slider);
}

.rc-slider-handle {
  border-color: var(--border-color-1-rc-slider);
  background-color: var(--background-color-3-rc-slider);
}

.rc-slider-handle:hover {
  border-color: var(--border-color-2-rc-slider);
}

.rc-slider-handle-active:active {
  border-color: var(--border-color-2-rc-slider);
  box-shadow: var(--border-color-2-rc-slider);
}

.rc-slider-mark-text {
  color: var(--color-1-rc-slider);
}

.rc-slider-mark-text-active {
  color: var(--color-2-rc-slider);
}

.rc-slider-step {
  background-color: var(--background-color-4-rc-slider);
}

.rc-slider-dot {
  border-color: var(--background-color-1-rc-slider);
  background-color: var(--background-color-3-rc-slider);
}

.rc-slider-dot-active {
  border-color: var(--border-color-1-rc-slider);
}

.rc-slider-disabled {
  background-color: var(--background-color-1-rc-slider);
}

.rc-slider-disabled .rc-slider-track {
  background-color: var(--background-color-5-rc-slider);
}

.rc-slider-disabled .rc-slider-handle,
.rc-slider-disabled .rc-slider-dot {
  border-color: var(--background-color-5-rc-slider);
  background-color: var(--background-color-3-rc-slider);
}

.rc-slider-tooltip-inner {
  color: var(--background-color-3-rc-slider);
  background-color: var(--background-color-6-rc-slider);
  box-shadow: var(--box-shadow-1-rc-slider);
}

.rc-slider-tooltip-arrow {
  border-color: var(--background-color-4-rc-slider);
}

.rc-slider-tooltip-placement-top .rc-slider-tooltip-arrow {
  border-top-color: var(--background-color-6-rc-slider);
}
