.CalendarDay {
  border-color: var(--border-color-1-react-dates);
  color: var(--color-1-react-dates); }

.CalendarDay__button {
  border-color: 0; }
  .CalendarDay__button:active {
    outline-color: 0; }

.CalendarDay--highlighted-calendar {
  background-color: var(--background-color-1-react-dates);
  color: var(--color-1-react-dates); }
  .CalendarDay--highlighted-calendar:active {
    background-color: var(--background-color-2-react-dates); }

.CalendarDay--outside {
  border-color: 0; }
  .CalendarDay--outside:active {
    background-color: var(--background-color-3-react-dates); }

.CalendarDay--hovered {
  background-color: var(--border-color-1-react-dates);
  border-color: var(--border-color-2-react-dates); }

.CalendarDay--blocked-minimum-nights {
  color: var(--color-2-react-dates);
  background-color: var(--background-color-3-react-dates);
  border-color: var(--border-color-1-react-dates); }
  .CalendarDay--blocked-minimum-nights:active {
    background-color: var(--background-color-3-react-dates); }

.CalendarDay--selected-span {
  background-color: var(--background-color-4-react-dates);
  border-color: var(--background-color-4-react-dates);
  color: var(--background-color-3-react-dates); }
  .CalendarDay--selected-span.CalendarDay--hovered, .CalendarDay--selected-span:active {
    background-color: var(--background-color-5-react-dates);
    border-color: var(--background-color-4-react-dates); }
  .CalendarDay--selected-span.CalendarDay--last-in-range {
    border-right-color: var(--background-color-5-react-dates); }

.CalendarDay--hovered-span,
.CalendarDay--after-hovered-start {
  background-color: var(--background-color-6-react-dates);
  border-color: var(--border-color-3-react-dates);
  color: var(--background-color-2-react-dates); }
  .CalendarDay--hovered-span:active,
  .CalendarDay--after-hovered-start:active {
    background-color: var(--border-color-3-react-dates); }

.CalendarDay--selected-start,
.CalendarDay--selected-end,
.CalendarDay--selected {
  background-color: var(--background-color-5-react-dates);
  border-color: var(--background-color-5-react-dates);
  color: var(--background-color-3-react-dates); }
  .CalendarDay--selected-start:active,
  .CalendarDay--selected-end:active,
  .CalendarDay--selected:active {
    background-color: var(--background-color-5-react-dates); }

.CalendarDay--blocked-calendar {
  background-color: var(--color-2-react-dates);
  color: var(--color-3-react-dates); }
  .CalendarDay--blocked-calendar:active {
    background-color: var(--color-2-react-dates); }

.CalendarDay--blocked-out-of-range {
  color: var(--color-2-react-dates);
  background-color: var(--background-color-3-react-dates);
  border-color: var(--border-color-1-react-dates); }
  .CalendarDay--blocked-out-of-range:active {
    background-color: var(--background-color-3-react-dates); }

.CalendarMonth__caption {
  color: var(--color-4-react-dates); }

.CalendarMonthGrid {
  background-color: var(--background-color-3-react-dates); }

.DayPicker {
  background-color: var(--background-color-3-react-dates); }

.DayPicker--horizontal {
  background-color: var(--background-color-3-react-dates);
  box-shadow: var(--box-shadow-2-react-dates); }

.DayPicker__week-header {
  color: var(--color-5-react-dates); }
  .DayPicker--vertical-scrollable .DayPicker__week-header {
    border-bottom-color: var(--border-bottom-color-1-react-dates);
    background-color: var(--background-color-7-react-dates); }

.DayPickerNavigation__prev--default,
.DayPickerNavigation__next--default {
  border-color: var(--border-color-4-react-dates);
  background-color: var(--background-color-3-react-dates);
  color: var(--color-5-react-dates); }
  .DayPickerNavigation__prev--default:focus, .DayPickerNavigation__prev--default:hover,
  .DayPickerNavigation__next--default:focus,
  .DayPickerNavigation__next--default:hover {
    border-color: var(--border-color-5-react-dates); }
  .DayPickerNavigation__prev--default:active,
  .DayPickerNavigation__next--default:active {
    background-color: var(--background-color-8-react-dates); }
  .DayPickerNavigation--horizontal .DayPickerNavigation__prev--default svg,
  .DayPickerNavigation--horizontal .DayPickerNavigation__next--default svg {
    fill: var(--color-3-react-dates); }

.DayPickerNavigation--vertical {
  background-color: var(--background-color-3-react-dates);
  box-shadow: var(--box-shadow-3-react-dates); }
  .DayPickerNavigation--vertical .DayPickerNavigation__next--default {
    border-left-color: 0; }
    .DayPickerNavigation--vertical .DayPickerNavigation__prev--default svg,
    .DayPickerNavigation--vertical .DayPickerNavigation__next--default svg {
      fill: var(--fill-1-react-dates); }

.DayPickerKeyboardShortcuts__show,
.DayPickerKeyboardShortcuts__close {
  border-color: 0; }

.DayPickerKeyboardShortcuts__show--bottom-right {
  border-top-color: var(--border-top-color-1-react-dates);
  border-right-color: var(--background-color-5-react-dates); }
  .DayPickerKeyboardShortcuts__show--bottom-right:hover {
    border-right-color: var(--border-right-color-1-react-dates); }

.DayPickerKeyboardShortcuts__show--top-right {
  border-bottom-color: var(--border-top-color-1-react-dates);
  border-right-color: var(--background-color-5-react-dates); }
  .DayPickerKeyboardShortcuts__show--top-right:hover {
    border-right-color: var(--border-right-color-1-react-dates); }

.DayPickerKeyboardShortcuts__show--top-left {
  border-bottom-color: var(--border-top-color-1-react-dates);
  border-left-color: var(--background-color-5-react-dates); }
  .DayPickerKeyboardShortcuts__show--top-left:hover {
    border-left-color: var(--border-right-color-1-react-dates); }

.DayPickerKeyboardShortcuts__show_span {
  color: var(--background-color-3-react-dates); }

.DayPickerKeyboardShortcuts__panel {
  background-color: var(--background-color-3-react-dates);
  border-color: var(--border-bottom-color-1-react-dates); }
  .DayPickerKeyboardShortcuts__close svg {
    fill: var(--color-2-react-dates); }
    .DayPickerKeyboardShortcuts__close svg:hover, .DayPickerKeyboardShortcuts__close svg:focus {
      fill: var(--color-3-react-dates); }

.KeyboardShortcutRow__key {
  background-color: var(--background-color-8-react-dates); }

.DateInput {
  color: var(--color-5-react-dates);
  background-color: var(--background-color-3-react-dates); }

.DateInput--with-caret::before,
.DateInput--with-caret::after {
  border-color: var(--border-top-color-1-react-dates);
  border-top-color: 0; }

.DateInput--with-caret::before {
  border-bottom-color: var(--box-shadow-3-react-dates); }

.DateInput--with-caret::after {
  border-bottom-color: var(--background-color-3-react-dates); }

.DateInput--disabled {
  background-color: var(--color-2-react-dates); }

.DateInput__input {
  border-color: 0; }

.DateInput__display-text--has-input {
  color: var(--fill-1-react-dates); }

.DateInput__display-text--focused {
  background-color: var(--background-color-9-react-dates);
  border-color: var(--background-color-9-react-dates);
  color: var(--background-color-2-react-dates); }

.screen-reader-only {
  border-color: 0; }

.DateRangePicker__picker {
  background-color: var(--background-color-3-react-dates); }

.DateRangePicker__picker--portal {
  background-color: var(--background-color-10-react-dates); }

.DateRangePicker__picker--full-screen-portal {
  background-color: var(--background-color-3-react-dates); }

.DateRangePicker__close {
  border-color: 0; }
  .DateRangePicker__close svg {
    fill: var(--color-2-react-dates); }
  .DateRangePicker__close:hover, .DateRangePicker__close:focus {
    color: var(--color-6-react-dates); }

.DateRangePickerInput {
  background-color: var(--background-color-3-react-dates);
  border-color: var(--color-2-react-dates); }

.DateRangePickerInput--disabled {
  background-color: var(--color-2-react-dates); }

.DateRangePickerInput__arrow svg {
  fill: var(--fill-1-react-dates); }

.DateRangePickerInput__clear-dates {
  border-color: 0; }

.DateRangePickerInput__clear-dates svg {
  fill: var(--color-3-react-dates); }

.DateRangePickerInput__clear-dates:focus,
.DateRangePickerInput__clear-dates--hover {
  background-color: var(--border-bottom-color-1-react-dates); }

.DateRangePickerInput__calendar-icon {
  border-color: 0; }
  .DateRangePickerInput__calendar-icon svg {
    fill: var(--color-3-react-dates); }

.SingleDatePicker__picker {
  background-color: var(--background-color-3-react-dates); }

.SingleDatePicker__picker--portal {
  background-color: var(--background-color-10-react-dates); }

.SingleDatePicker__picker--full-screen-portal {
  background-color: var(--background-color-3-react-dates); }

.SingleDatePicker__close {
  border-color: 0; }
  .SingleDatePicker__close svg {
    fill: var(--color-2-react-dates); }
  .SingleDatePicker__close:hover, .SingleDatePicker__close:focus {
    color: var(--color-6-react-dates); }

.SingleDatePickerInput {
  background-color: var(--background-color-3-react-dates);
  border-color: var(--border-bottom-color-1-react-dates); }

.SingleDatePickerInput__clear-date {
  border-color: 0; }

.SingleDatePickerInput__clear-date svg {
  fill: var(--color-3-react-dates); }

.SingleDatePickerInput__clear-date:focus,
.SingleDatePickerInput__clear-date--hover {
  background-color: var(--border-bottom-color-1-react-dates); }

.SingleDatePickerInput__calendar-icon {
  border-color: 0; }
  .SingleDatePickerInput__calendar-icon svg {
    fill: var(--color-3-react-dates); }
