.button,
button,
input[type="submit"],
input[type="reset"],
input[type="button"] {
    border-radius: var(--button-border-radius);
}

input:not([type]),
input[type="email"],
input[type="number"],
input[type="search"],
input[type="text"],
input[type="tel"],
input[type="url"],
input[type="password"],
textarea,
select {
    border-left-width: var(--input-border-width);
    border-right-width: var(--input-border-width);
    border-top-width: var(--input-border-width);
    border-radius: var(--input-border-radius);
}

input:disabled {
    color: var(--color-7-base);
    background-color: var(--background-color-4-base);
    border-bottom: none;
}
