.Select-input > input {
  background-color: var(--background-color-7-react-select);
  border-color: 0;
}

.Select-arrow {
    border-top-color: var(--background-color-8-react-select);
    border-left-color: transparent;
    border-right-color: transparent;
    border-bottom-color: transparent;
}

.is-open > .Select-control .Select-arrow {
    border-bottom-color: var(--background-color-8-react-select);
    border-left-color: transparent;
    border-right-color: transparent;
    border-top-color: transparent;
}

.Select--multi .Select-value,
.Select--multi a.Select-value-label {
    color: var(--color-8-react-select);
}

.Select {
    border-radius: 0;
}

.Select-control {
    border-left-width: var(--input-border-width);
    border-right-width: var(--input-border-width);
    border-top-width: var(--input-border-width);
    border-radius: var(--input-border-radius);
}

.Select.is-disabled > .Select-control {
    border: none;
}

.Select-control:hover {
    border-color: var(--border-color-9-react-select);
    cursor: pointer;
}

.Select--multi .Select-value-icon:hover, .Select--multi .Select-value-icon:focus {
    font-weight: bold;
}

.Select.is-disabled .Select-control {
    cursor: not-allowed;
}
