html {
    box-sizing: border-box;
}
*, *:before, *:after {
    box-sizing: inherit;
}

.app {
    margin-top: 10vh;
    margin-left: 10vw;
    background-color: rgb(245, 245, 245);
    padding: 50px;
    border-radius: 5px;
}

.ColorTab:first-child .ColorTab--title {
    border-top-left-radius: 10px;
}
.ColorTab:first-child .ColorTab--footer {
    border-bottom-left-radius: 10px;
}

.ColorTab:last-child .ColorTab--title {
    border-top-right-radius: 10px;
    border-right: 1px lightgrey solid;
}
.ColorTab:last-child .ColorTab--footer {
    border-bottom-right-radius: 10px;
    border-right: 1px lightgrey solid;
}

.ColorTab {
    float: left;
    width: 150px;
    height: 300px;
}

.ColorTab--panel {
    width: 100%;
    height: calc(100% - 40px);
    border-left: thin lightgrey solid;
}
.ColorTab--label {
    text-align: center;
    font-size: 12px;
    text-overflow: ellipsis;
    line-height: 20px;
    height: 20px;
    font-family: monospace;
    color: #506784;
}
.ColorTab--title {
    border-top: 1px lightgrey solid;
    border-left: 1px lightgrey solid;
    border-bottom: 1px lightgrey solid;
}
.ColorTab--footer {
    border-top: 1px lightgrey solid;
    border-left: 1px lightgrey solid;
    border-bottom: 1px lightgrey solid;
}
.ColorTab--input {
    background-color: transparent;
    border: none;
    font-family: monospace;
    text-align: center;
}

.ColorTab--strip {
    width: 100%;
}
.Settings {
    margin-bottom: 50px;
}
.Settings--title-container {
    width: 100%;
}
.Settings--title {
    font-family: monospace;
    color: #506784;
    height: 30px;
    line-height: 30px;
    font-size: 20px;
    margin-left: 5px;
    float: left;
}

.cf,
.Settings:after {
    content: "";
    display: table;
    clear: both;
}

.ColorTab--editor {
    height: 100%;
    width: 34%;
    margin-left: 66%;
    background-color: white;
    z-index: 20;
    position: relative;
    top: 0;
}

.ColorRoll {
    width: 100%;
    height: 100%;
    border-bottom-left-radius: 5px;
    border-bottom-right-radius: 5px;
}
.ColorTab--editor {
     transition: opacity 300ms;
     opacity: 1;
}
.ColorTab--editor.hidden {
    opacity: 0;
}

.ColorRoll--slice {
    height: 30px;
    border-top: thin lightgrey solid;
    border-left: thin lightgrey solid;
    cursor: pointer;
}

.Editor {
    .Select-control {
        border: none;
        height: 35px;
        border-radius: 5px;
        background-color: rgb(245, 245, 245);
    }
}

.ColorWayPicker--option {
    height: 30px;
    padding: 5px;
}

.ColorWayPicker--option-item {
    display: inline-block;
    width: 25px;
    height: 25px;
}
.ColorWayPicker--option-item:first-child {
    border-top-left-radius: 5px;
    border-bottom-left-radius: 5px;
}

.ColorWayPicker--option-item:last-child {
    border-top-right-radius: 5px;
    border-bottom-right-radius: 5px;
}
.ColorWayPicker--container {
    height: 35px;
    width: 180px;
    float: right;
}
.accent-toggle {
    font-family: monospace;
    color: #506784;
    height: 20px;
    line-height: 20px;
    font-size: 14px;
}
