.Select.is-disabled > .Select-control {
  background-color: var(--background-color-1-react-select);
}
.Select-control {
  background-color: var(--background-color-2-react-select);
  border-color: var(--border-color-3-react-select);
  border-color: var(--border-color-2-react-select);
  color: var(--color-1-react-select);
}
.Select-control:hover {
  box-shadow: var(--box-shadow-1-react-select);
}
.is-open > .Select-control {
  background-color: var(--background-color-2-react-select);
  border-color: var(--border-color-1-react-select);
}
.is-open > .Select-control .Select-arrow {
  border-color: var(--border-color-5-react-select);
}
.is-focused:not(.is-open) > .Select-control {
  border-color: var(--border-color-6-react-select);
  box-shadow: var(--box-shadow-3-react-select);
}
.Select-placeholder,
.Select--single > .Select-control .Select-value {
  color: var(--color-2-react-select);
}
.has-value.Select--single > .Select-control .Select-value .Select-value-label,
.has-value.is-pseudo-focused.Select--single > .Select-control .Select-value .Select-value-label {
  color: var(--color-1-react-select);
}
.has-value.Select--single > .Select-control .Select-value a.Select-value-label:hover,
.has-value.is-pseudo-focused.Select--single > .Select-control .Select-value a.Select-value-label:hover,
.has-value.Select--single > .Select-control .Select-value a.Select-value-label:focus,
.has-value.is-pseudo-focused.Select--single > .Select-control .Select-value a.Select-value-label:focus {
  color: var(--border-color-6-react-select);
}
.Select-input > input {
  background-color: var(--border-color-4-react-select);
  border-color: 0;
}
.Select-loading {
  border-color: var(--border-color-2-react-select);
  border-right-color: var(--color-1-react-select);
}
.Select-clear-zone {
  color: var(--border-color-5-react-select);
}
.Select-clear-zone:hover {
  color: var(--color-3-react-select);
}
.Select-arrow {
  border-color: var(--border-color-4-react-select);
}
.is-open .Select-arrow,
.Select-arrow-zone:hover > .Select-arrow {
  border-top-color: var(--border-top-color-1-react-select);
}
.Select-menu-outer {
  background-color: var(--background-color-2-react-select);
  border-color: var(--border-color-2-react-select);
  border-top-color: var(--border-top-color-2-react-select);
  box-shadow: var(--box-shadow-1-react-select);
}
.Select-option {
  background-color: var(--background-color-2-react-select);
  color: var(--color-4-react-select);
}
.Select-option.is-selected {
  background-color: var(--background-color-3-react-select);
  color: var(--color-1-react-select);
}
.Select-option.is-focused {
  background-color: var(--background-color-4-react-select);
  color: var(--color-1-react-select);
}
.Select-option.is-disabled {
  color: var(--color-5-react-select);
}
.Select-noresults {
  color: var(--color-6-react-select);
}
.Select--multi .Select-value {
  background-color: var(--background-color-4-react-select);
  border-color: var(--border-color-7-react-select);
  color: var(--border-color-6-react-select);
}
.Select--multi a.Select-value-label {
  color: var(--border-color-6-react-select);
}
.Select--multi .Select-value-icon {
  border-right-color: var(--border-color-7-react-select);
}
.Select--multi .Select-value-icon:hover,
.Select--multi .Select-value-icon:focus {
  background-color: var(--background-color-5-react-select);
  color: var(--color-7-react-select);
}
.Select--multi .Select-value-icon:active {
  background-color: var(--border-color-7-react-select);
}
.Select--multi.is-disabled .Select-value {
  background-color: var(--background-color-6-react-select);
  border-color: var(--border-color-8-react-select);
  color: var(--color-1-react-select);
}
.Select--multi.is-disabled .Select-value-icon {
  border-right-color: var(--border-color-8-react-select);
}
.Select--multi.is-disabled .Select-value-icon:hover,
.Select--multi.is-disabled .Select-value-icon:focus,
.Select--multi.is-disabled .Select-value-icon:active {
  background-color: var(--background-color-6-react-select);
}
