body {
  color: var(--color-1-base);
  background-color: var(--background);
}
blockquote {
  border-left-color: var(--border-left-color-1-base);
}
a {
  color: var(--color-2-base);}
a:hover {
  color: var(--color-3-base); }
.button,
button,
input[type="submit"],
input[type="reset"],
input[type="button"] {
  color: var(--trace-1);
  background-color: var(--background-color-1-base);
  border-color: var(--border-color-1-base);
  transition: all 0.2s ease;
  box-shadow: 0 4px 6px var(--button-shadow);
}

.button:active,
button:active,
input[type="submit"]:active,
input[type="reset"]:active,
input[type="button"]:active {
    box-shadow: none;
}
.button:hover:enabled,
button:hover:enabled,
input[type="submit"]:hover:enabled,
input[type="reset"]:hover:enabled,
input[type="button"]:hover:enabled,
.button:focus,
button:focus,
input[type="submit"]:focus,
input[type="reset"]:focus,
input[type="button"]:focus {
  color: var(--color-5-base);
  border-color: var(--border-color-2-base);
  outline-color: 0; }
.button.button-primary,
button.button-primary,
input[type="submit"].button-primary,
input[type="reset"].button-primary,
input[type="button"].button-primary {
  color: var(--background);
  background-color: var(--trace-1);
  border-color: var(--trace-1); }
.button.button-primary:hover:enabled,
button.button-primary:hover:enabled,
input[type="submit"].button-primary:hover:enabled,
input[type="reset"].button-primary:hover:enabled,
input[type="button"].button-primary:hover:enabled,
.button.button-primary:focus,
button.button-primary:focus,
input[type="submit"].button-primary:focus,
input[type="reset"].button-primary:focus,
input[type="button"].button-primary:focus {
  color: var(--trace-1);
  background-color: var(--background);
  border-color: var(--trace-1); }
input:not([type]),
input[type="email"],
input[type="number"],
input[type="search"],
input[type="text"],
input[type="tel"],
input[type="url"],
input[type="password"],
textarea,
select {
  background-color: var(--background-color-3-base);
  border-color: var(--border-color-3-base);}
input[type="email"]:focus,
input[type="number"]:focus,
input[type="search"]:focus,
input[type="text"]:focus,
input[type="tel"]:focus,
input[type="url"]:focus,
input[type="password"]:focus,
textarea:focus,
select:focus,
input[type="email"]:hover:enabled,
input[type="number"]:hover:enabled,
input[type="search"]:hover:enabled,
input[type="text"]:hover:enabled,
input[type="tel"]:hover:enabled,
input[type="url"]:hover:enabled,
input[type="password"]:hover:enabled,
textarea:hover:enabled,
select:hover:enabled {
  border-color: var(--background-color-2-base);
  outline-color: 0; }
th,
td {
  border-bottom-color: var(--border-bottom-color-1-base); }
hr {
  border-top-color: var(--border-bottom-color-1-base); }
